pub struct SessionConfig {
pub session_type: u8,
pub p2_timeout: Duration,
pub p2_extended_timeout: Duration,
pub s3_timeout: Duration,
}Expand description
Configuration for a single UDS diagnostic session.
Mirrors the session configuration in an ODX ECU-DESC container.
Fields
session_type: u8UDS session type byte. 0x01 Default Session, 0x02 Programming Session, 0x03 ExtendedSession.
p2_timeout: DurationP2 server - max time to respond before the tester times out (ms)
p2_extended_timeout: DurationP2* server - max time after sending 0x78 Response Pending before the final response must be sent (ms)
s3_timeout: DurationS3 server - max time between Tester Present messages before the server drops back to Default Session (ms)
Implementations
Sourceimpl SessionConfig
impl SessionConfig
pub const fn default_session() -> Self
pub const fn programming_session() -> Self
pub const fn extended_session() -> Self