Module nrc

Module nrc 

Enums

BuiltinNrc
A built-in NRC type covering all codes the server may emit.

Traits

NrcError
A trait for application error types that can be converted into UDS Negative Response Codes (NRCs).