BuiltinNrc

Enum BuiltinNrc 

#[repr(u8)]
pub enum BuiltinNrc {
Show 17 variants ServiceNotSupported = 17, SubFunctionNotSupported = 18, IncorrectMessageLengthOrInvalidFormat = 19, ConditionsNotCorrect = 34, RequestSequenceError = 36, RequestOutOfRange = 49, SecurityAccessDenied = 51, InvalidKey = 53, ExceededNumberOfAttempts = 54, RequiredTimeDelayNotExpired = 55, UploadDownloadNotAccepted = 112, TransferDataSuspended = 113, GeneralProgrammingFailure = 114, WrongBlockSequenceCounter = 115, ResponsePending = 120, SubFunctionNotSupportedInActiveSession = 126, ServiceNotSupportedInActiveSession = 127,
}
A built-in NRC type covering all codes the server may emit.

Applications that do not need a custom error type may use this directly as type Error = BuiltinNrc in the ServerHandler impl.

Variants



ServiceNotSupported = 17



SubFunctionNotSupported = 18



IncorrectMessageLengthOrInvalidFormat = 19



ConditionsNotCorrect = 34



RequestSequenceError = 36



RequestOutOfRange = 49



SecurityAccessDenied = 51



InvalidKey = 53



ExceededNumberOfAttempts = 54



RequiredTimeDelayNotExpired = 55



UploadDownloadNotAccepted = 112



TransferDataSuspended = 113



GeneralProgrammingFailure = 114



WrongBlockSequenceCounter = 115



ResponsePending = 120



SubFunctionNotSupportedInActiveSession = 126



ServiceNotSupportedInActiveSession = 127