pub trait NrcError: Into<u8> + Debug {
Show 17 methods
// Required methods
fn service_not_supported() -> Self;
fn sub_function_not_supported() -> Self;
fn incorrect_message_length_or_invalid_format() -> Self;
fn conditions_not_correct() -> Self;
fn request_sequence_error() -> Self;
fn request_out_of_range() -> Self;
fn security_access_denied() -> Self;
fn invalid_key() -> Self;
fn exceeded_number_of_attempts() -> Self;
fn required_time_delay_not_expired() -> Self;
fn upload_download_not_accepted() -> Self;
fn transfer_data_suspended() -> Self;
fn general_programming_failure() -> Self;
fn wrong_block_sequence_counter() -> Self;
fn response_pending() -> Self;
fn sub_function_not_supported_in_active_session() -> Self;
fn service_not_supported_in_active_session() -> Self;
}Expand description
A trait for application error types that can be converted into UDS Negative Response Codes (NRCs).
The server state machine uses this to construct NRC responses without knowing the application’s
error type internals. The application defines the mapping via Into<u8>.
Required Methods
Sourcefn service_not_supported() -> Self
fn service_not_supported() -> Self
0x11 - serviceNotSupported
Sourcefn sub_function_not_supported() -> Self
fn sub_function_not_supported() -> Self
0x12 - subFunctionNotSupported
Sourcefn incorrect_message_length_or_invalid_format() -> Self
fn incorrect_message_length_or_invalid_format() -> Self
0x13 - incorrectMessageLengthOrInvalidFormat
Sourcefn conditions_not_correct() -> Self
fn conditions_not_correct() -> Self
0x22 - conditionsNotCorrect
Sourcefn request_sequence_error() -> Self
fn request_sequence_error() -> Self
0x24 - requestSequenceError
Sourcefn request_out_of_range() -> Self
fn request_out_of_range() -> Self
0x31 - requestOutOfRange
Sourcefn security_access_denied() -> Self
fn security_access_denied() -> Self
0x33 - securityAccessDenied
Sourcefn invalid_key() -> Self
fn invalid_key() -> Self
0x35 - invalidKey
Sourcefn exceeded_number_of_attempts() -> Self
fn exceeded_number_of_attempts() -> Self
0x36 - exceededNumberOfAttempts
Sourcefn required_time_delay_not_expired() -> Self
fn required_time_delay_not_expired() -> Self
0x37 - requiredTimeDelayNotExpired
Sourcefn upload_download_not_accepted() -> Self
fn upload_download_not_accepted() -> Self
0x70 - uploadDownloadNotAccepted
Sourcefn transfer_data_suspended() -> Self
fn transfer_data_suspended() -> Self
0x71 - transferDataSuspended
Sourcefn general_programming_failure() -> Self
fn general_programming_failure() -> Self
0x72 - generalProgrammingFailure
Sourcefn wrong_block_sequence_counter() -> Self
fn wrong_block_sequence_counter() -> Self
0x73 - wrongBlockSequenceCounter
Sourcefn response_pending() -> Self
fn response_pending() -> Self
0x78 - requestCorrectlyReceivedResponsePending
Sourcefn sub_function_not_supported_in_active_session() -> Self
fn sub_function_not_supported_in_active_session() -> Self
0x7E - subFunctionNotSupportedInActiveSession
Sourcefn service_not_supported_in_active_session() -> Self
fn service_not_supported_in_active_session() -> Self
0x7F - serviceNotSupportedInActiveSession
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".